(function(global) {
	var baseURL= '/',
		basePosterURL = '/';

	/**
	 * Fetch the text data that will be used by the templatew
	 * @param  {Function} callback Callback with err or with the fetched data
	 */
	function fetchTextData (callback) {
		var request = new XMLHttpRequest(),
			endpoint = baseURL + '/TXITENS.TXT' + '?t=' + Date.now(); // Cache-buster timestamp

		request.open('GET', endpoint, true);
		request.onload = function() {
			if (this.status >= 200 && this.status < 400) {
				if (this.response.length > 0) {
					callback(null, this.response);
				} else {
					displayError('Empty response!');
					callback(204);
				}
			} else {
				displayError('XHR Status ' + this.status);
				callback('ERROR: Status ' + this.status);
			}
		};
		request.onerror = function() {
			displayError('XHR ERROR!');
			callback('ERROR: XHR ERROR!');
		};
		request.send();
	}

	/**
	 * Receive the text data and parses it
	 * @param  {String} textData Data as fetched
	 * @return {Object}          Parsed Data
	 */
	function parseTextData (textData) {
		var lines = textData.split(/\r?\n/),
			products = [];

		lines.forEach(function(line, i) {
			// Session
			products.push({
				departamento : line.substring(0, 2), // DEPARTAMENO
				tipoEtiqueta : line.substring(2, 4), // TIPO DE ETIQUETA
				tipoProduto : line.substring(4, 5), // TIPO DEPRODUTO
				codigoItem : line.substring(5, 11), //CÓDIGO DO ITEM
				precoProduto : formatReal(parseInt(line.substring(11, 17))), //PREÇO DO PRODUTO
				validade : line.substring(17, 20), //VALIDADE
				nomeProduto : line.substring(20) //NOME DO PRODUTO
			});
		});

		return products;
	}

	function formatReal( int ) {
        var tmp = int+'';
        tmp = tmp.replace(/([0-9]{2})$/g, ",$1");
        if( tmp.length > 6 )
                tmp = tmp.replace(/([0-9]{3}),([0-9]{2}$)/g, ".$1,$2");

        return tmp;
	}

	var displayError = console.error;

	global.shibata = {
		/**
		 * Returns the update data already parsed
		 * @param  {Function} callback (err,data)
		 */
		fetchData : function(config, callback) {
			if (config) {
				baseURL = config.baseURL || '';
				basePosterURL = config.basePosterURL || '';
			}
			fetchTextData(function(err, data) {
				if (err) {
					callback(err);
				} else {
					callback(null, parseTextData(data));
				}
			});
		}
	};

})(window);

